"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const FileHelpers = require("./file-helpers");
const model_1 = require("./model");
const template_content_sync_1 = require("./template-content-sync");
const OPTIONS = {
    cleanOutDir: true,
    config: "./ifc.json",
    fileEncoding: "utf-16",
    lineRegExp: "",
    outDir: "outDirPath",
    srcDir: "srcDirPath",
    tokens: {
        "<!-- again header here -->": "./header.html",
        "<!-- body here -->": "./body.html",
        "<!-- header here -->": "./header.html",
        "version-number": "./version.txt",
    },
};
const CONTENT = `
<!DOCTYPE html>
<html>
<head>
    <title>Page Title</title>
</head>
<body>
    <!-- header here -->
    <!-- again header here -->
    <!-- body here -->
    <!-- body here -->
    version: version-number
    <!-- filename=./templates/footer.html -->
    <!-- No token here -->
</body>
</html>`;
const TOKEN_REPLCED_CONTENT = `
<!DOCTYPE html>
<html>
<head>
    <title>Page Title</title>
</head>
<body>
    This is header
    This is header
    This is body
    This is body
    version: 1.0.0.1
    <!-- filename=./templates/footer.html -->
    <!-- No token here -->
</body>
</html>`;
const LINE_REPLACED_CONTENT = `
<!DOCTYPE html>
<html>
<head>
    <title>Page Title</title>
</head>
<body>
    <!-- header here -->
    <!-- again header here -->
    <!-- body here -->
    <!-- body here -->
    version: version-number
This is footer
    <!-- No token here -->
</body>
</html>`;
const REPLCED_CONTENT = `
<!DOCTYPE html>
<html>
<head>
    <title>Page Title</title>
</head>
<body>
    This is header
    This is header
    This is body
    This is body
    version: 1.0.0.1
This is footer
    <!-- No token here -->
</body>
</html>`;
describe("Template Content Sync:", () => {
    let getFileContentSyncSpy;
    beforeEach(() => {
        getFileContentSyncSpy = spyOn(FileHelpers, "getFileContentSync").and.callFake((path) => {
            let content = "";
            switch (path) {
                case "./header.html":
                    content = "This is header";
                    break;
                case "./body.html":
                    content = "This is body";
                    break;
                case "./version.txt":
                    content = "1.0.0.1";
                    break;
                case "./templates/footer.html":
                    content = "This is footer";
                    break;
                case "./empty.html":
                    content = "";
                    break;
                case "./recursion.html":
                    content = "recursion + <!-- body here --> + recursion";
                    break;
            }
            return content;
        });
    });
    it("should return orginal content when no tokens are matched", () => {
        expect(template_content_sync_1.replaceTokensAndLineRegExpSync(CONTENT, model_1.defaultOptions)).toEqual(CONTENT);
    });
    it("should replace given tokens", () => {
        const replacedContent = template_content_sync_1.replaceTokensAndLineRegExpSync(CONTENT, OPTIONS);
        expect(replacedContent).toEqual(TOKEN_REPLCED_CONTENT);
    });
    it("should replace given lineRegExp", () => {
        const newOptions = Object.assign({}, OPTIONS, { tokens: {}, lineRegExp: "filename=(.*.html)" });
        expect(template_content_sync_1.replaceTokensAndLineRegExpSync(CONTENT, newOptions)).toEqual(LINE_REPLACED_CONTENT);
    });
    it("should replace both tokens and lineRegExp", () => {
        const newOptions = Object.assign({}, OPTIONS, { lineRegExp: "filename=(.*.html)" });
        expect(template_content_sync_1.replaceTokensAndLineRegExpSync(CONTENT, newOptions)).toEqual(REPLCED_CONTENT);
    });
    it("should replace both tokens and lineRegExp", () => {
        const newOptions = Object.assign({}, OPTIONS, { lineRegExp: "filename=(.*.html)" });
        expect(template_content_sync_1.replaceTokensAndLineRegExpSync(CONTENT, newOptions)).toEqual(REPLCED_CONTENT);
    });
    it("getFileContentSync should be called unique file path times", () => {
        template_content_sync_1.clearCache();
        template_content_sync_1.replaceTokensAndLineRegExpSync(CONTENT, Object.assign({}, OPTIONS, { lineRegExp: "filename=(.*.html)" }));
        expect(getFileContentSyncSpy).toHaveBeenCalledTimes(4);
    });
    it("should load template content from cache", () => {
        template_content_sync_1.clearCache();
        template_content_sync_1.replaceTokensAndLineRegExpSync(CONTENT, Object.assign({}, OPTIONS, { lineRegExp: "filename=(.*.html)" }));
        template_content_sync_1.replaceTokensAndLineRegExpSync(CONTENT, Object.assign({}, OPTIONS, { lineRegExp: "filename=(.*.html)" }));
        template_content_sync_1.replaceTokensAndLineRegExpSync(CONTENT, Object.assign({}, OPTIONS, { lineRegExp: "filename=(.*.html)" }));
        expect(getFileContentSyncSpy).toHaveBeenCalledTimes(4);
    });
    it("should not replace token with empty content", () => {
        template_content_sync_1.clearCache();
        const cstr = `some content <!-- header here --> <!-- empty content token --> <!-- body here --> footer data`;
        const replacedContentStr = `some content This is header <!-- empty content token --> This is body footer data`;
        const newOptions = Object.assign({}, OPTIONS, {
            tokens: {
                "<!-- body here -->": "./body.html",
                "<!-- empty content token -->": "./empty.html",
                "<!-- header here -->": "./header.html",
            },
        });
        expect(template_content_sync_1.replaceTokensAndLineRegExpSync(cstr, newOptions)).toEqual(replacedContentStr);
    });
    it("should replace recursion token with content", () => {
        const contentStr = `some content <!-- header here --> <!-- recursion here --> footer data`;
        const replacedContentStr = `some content This is header recursion + This is body + recursion footer data`;
        const newOptions = Object.assign({}, OPTIONS, {
            tokens: {
                "<!-- body here -->": "./body.html",
                "<!-- header here -->": "./header.html",
                "<!-- recursion here -->": "./recursion.html",
            },
        });
        expect(template_content_sync_1.replaceTokensAndLineRegExpSync(contentStr, newOptions)).toEqual(replacedContentStr);
    });
});
